import ares_data_schema_pb2 as _ares_data_schema_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GlobalVariableSymbol(_message.Message):
    __slots__ = ("name", "description", "schema", "value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    schema: _ares_data_schema_pb2.AresValueSchema
    value: _ares_struct_pb2.AresValue
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., schema: _Optional[_Union[_ares_data_schema_pb2.AresValueSchema, _Mapping]] = ..., value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ...) -> None: ...
