"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_scripting_service.proto')
_sym_db = _symbol_database.Default()
from . import ares_struct_pb2 as ares__struct__pb2
from .scripting import completion_pb2 as scripting_dot_completion__pb2
from .scripting import diagnostic_pb2 as scripting_dot_diagnostic__pb2
from .scripting import navigation_pb2 as scripting_dot_navigation__pb2
from .scripting import script_summary_step_pb2 as scripting_dot_script__summary__step__pb2
from .scripting import script_symbol_metadata_pb2 as scripting_dot_script__symbol__metadata__pb2
from .scripting import signature_help_pb2 as scripting_dot_signature__help__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cares_scripting_service.proto\x12\rares.services\x1a\x11ares_struct.proto\x1a\x1ascripting/completion.proto\x1a\x1ascripting/diagnostic.proto\x1a\x1ascripting/navigation.proto\x1a#scripting/script_summary_step.proto\x1a&scripting/script_symbol_metadata.proto\x1a\x1escripting/signature_help.proto"(\n\x16ScriptExecutionRequest\x12\x0e\n\x06script\x18\x01 \x01(\t"\xdb\x03\n\x14ScriptExecutionEvent\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12<\n\x11execution_started\x18\x02 \x01(\x0b2\x1f.ares.services.ExecutionStartedH\x00\x12@\n\x13execution_completed\x18\x03 \x01(\x0b2!.ares.services.ExecutionCompletedH\x00\x12:\n\x10execution_failed\x18\x04 \x01(\x0b2\x1e.ares.services.ExecutionFailedH\x00\x126\n\x0econsole_output\x18\x05 \x01(\x0b2\x1c.ares.services.ConsoleOutputH\x00\x12:\n\x10function_started\x18\x06 \x01(\x0b2\x1e.ares.services.FunctionStartedH\x00\x12>\n\x12function_completed\x18\x07 \x01(\x0b2 .ares.services.FunctionCompletedH\x00\x128\n\x0ffunction_failed\x18\x08 \x01(\x0b2\x1d.ares.services.FunctionFailedH\x00B\x07\n\x05event"\x12\n\x10ExecutionStarted"\x14\n\x12ExecutionCompleted" \n\x0fExecutionFailed\x12\r\n\x05error\x18\x01 \x01(\t"\x1f\n\rConsoleOutput\x12\x0e\n\x06output\x18\x01 \x01(\t"\x82\x01\n\x0fFunctionStarted\x12\x0f\n\x07call_id\x18\x01 \x01(\t\x12\x16\n\x0eparent_call_id\x18\x02 \x01(\t\x12F\n\ninvocation\x18\x03 \x01(\x0b22.ares.datamodel.scripting.ScriptFunctionInvocation"O\n\x11FunctionCompleted\x12\x0f\n\x07call_id\x18\x01 \x01(\t\x12)\n\x06result\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue"0\n\x0eFunctionFailed\x12\x0f\n\x07call_id\x18\x01 \x01(\t\x12\r\n\x05error\x18\x02 \x01(\t"\'\n\x15ValidateScriptRequest\x12\x0e\n\x06script\x18\x01 \x01(\t"S\n\x16ValidateScriptResponse\x129\n\x0bdiagnostics\x18\x01 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"_\n\x14ScriptSummaryRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x1e\n\x16include_user_functions\x18\x02 \x01(\x08\x12\x17\n\x0finclude_lambdas\x18\x03 \x01(\x08"\x95\x01\n\x15ScriptSummaryResponse\x12A\n\x05steps\x18\x01 \x03(\x0b22.ares.datamodel.scripting.ScriptFunctionInvocation\x129\n\x0bdiagnostics\x18\x02 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"{\n\x15SymbolMetadataRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05\x12\x17\n\nidentifier\x18\x04 \x01(\tH\x00\x88\x01\x01B\r\n\x0b_identifier"\xa4\x01\n\x16SymbolMetadataResponse\x12\r\n\x05found\x18\x01 \x01(\x08\x12@\n\x08metadata\x18\x02 \x01(\x0b2..ares.datamodel.scripting.ScriptSymbolMetadata\x129\n\x0bdiagnostics\x18\x03 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"\x93\x01\n\x11ReferencesRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05\x12\x17\n\nidentifier\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12include_definition\x18\x05 \x01(\x08B\r\n\x0b_identifier"\x8c\x01\n\x12ReferencesResponse\x12;\n\tlocations\x18\x01 \x03(\x0b2(.ares.datamodel.scripting.SymbolLocation\x129\n\x0bdiagnostics\x18\x02 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"R\n\x14SignatureHelpRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05"\x93\x01\n\x15SignatureHelpResponse\x12?\n\x0esignature_help\x18\x01 \x01(\x0b2\'.ares.datamodel.scripting.SignatureHelp\x129\n\x0bdiagnostics\x18\x02 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"j\n\x11CompletionRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05\x12\x19\n\x11trigger_character\x18\x04 \x01(\t"M\n\x12CompletionResponse\x127\n\x05items\x18\x01 \x03(\x0b2(.ares.datamodel.scripting.CompletionItem2\xa1\x05\n\x14AresScriptingService\x12]\n\rExecuteScript\x12%.ares.services.ScriptExecutionRequest\x1a#.ares.services.ScriptExecutionEvent0\x01\x12U\n\x0eGetCompletions\x12 .ares.services.CompletionRequest\x1a!.ares.services.CompletionResponse\x12]\n\x0eValidateScript\x12$.ares.services.ValidateScriptRequest\x1a%.ares.services.ValidateScriptResponse\x12]\n\x10GetScriptSummary\x12#.ares.services.ScriptSummaryRequest\x1a$.ares.services.ScriptSummaryResponse\x12`\n\x11GetSymbolMetadata\x12$.ares.services.SymbolMetadataRequest\x1a%.ares.services.SymbolMetadataResponse\x12T\n\rGetReferences\x12 .ares.services.ReferencesRequest\x1a!.ares.services.ReferencesResponse\x12]\n\x10GetSignatureHelp\x12#.ares.services.SignatureHelpRequest\x1a$.ares.services.SignatureHelpResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_scripting_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTEXECUTIONREQUEST']._serialized_start = 259
    _globals['_SCRIPTEXECUTIONREQUEST']._serialized_end = 299
    _globals['_SCRIPTEXECUTIONEVENT']._serialized_start = 302
    _globals['_SCRIPTEXECUTIONEVENT']._serialized_end = 777
    _globals['_EXECUTIONSTARTED']._serialized_start = 779
    _globals['_EXECUTIONSTARTED']._serialized_end = 797
    _globals['_EXECUTIONCOMPLETED']._serialized_start = 799
    _globals['_EXECUTIONCOMPLETED']._serialized_end = 819
    _globals['_EXECUTIONFAILED']._serialized_start = 821
    _globals['_EXECUTIONFAILED']._serialized_end = 853
    _globals['_CONSOLEOUTPUT']._serialized_start = 855
    _globals['_CONSOLEOUTPUT']._serialized_end = 886
    _globals['_FUNCTIONSTARTED']._serialized_start = 889
    _globals['_FUNCTIONSTARTED']._serialized_end = 1019
    _globals['_FUNCTIONCOMPLETED']._serialized_start = 1021
    _globals['_FUNCTIONCOMPLETED']._serialized_end = 1100
    _globals['_FUNCTIONFAILED']._serialized_start = 1102
    _globals['_FUNCTIONFAILED']._serialized_end = 1150
    _globals['_VALIDATESCRIPTREQUEST']._serialized_start = 1152
    _globals['_VALIDATESCRIPTREQUEST']._serialized_end = 1191
    _globals['_VALIDATESCRIPTRESPONSE']._serialized_start = 1193
    _globals['_VALIDATESCRIPTRESPONSE']._serialized_end = 1276
    _globals['_SCRIPTSUMMARYREQUEST']._serialized_start = 1278
    _globals['_SCRIPTSUMMARYREQUEST']._serialized_end = 1373
    _globals['_SCRIPTSUMMARYRESPONSE']._serialized_start = 1376
    _globals['_SCRIPTSUMMARYRESPONSE']._serialized_end = 1525
    _globals['_SYMBOLMETADATAREQUEST']._serialized_start = 1527
    _globals['_SYMBOLMETADATAREQUEST']._serialized_end = 1650
    _globals['_SYMBOLMETADATARESPONSE']._serialized_start = 1653
    _globals['_SYMBOLMETADATARESPONSE']._serialized_end = 1817
    _globals['_REFERENCESREQUEST']._serialized_start = 1820
    _globals['_REFERENCESREQUEST']._serialized_end = 1967
    _globals['_REFERENCESRESPONSE']._serialized_start = 1970
    _globals['_REFERENCESRESPONSE']._serialized_end = 2110
    _globals['_SIGNATUREHELPREQUEST']._serialized_start = 2112
    _globals['_SIGNATUREHELPREQUEST']._serialized_end = 2194
    _globals['_SIGNATUREHELPRESPONSE']._serialized_start = 2197
    _globals['_SIGNATUREHELPRESPONSE']._serialized_end = 2344
    _globals['_COMPLETIONREQUEST']._serialized_start = 2346
    _globals['_COMPLETIONREQUEST']._serialized_end = 2452
    _globals['_COMPLETIONRESPONSE']._serialized_start = 2454
    _globals['_COMPLETIONRESPONSE']._serialized_end = 2531
    _globals['_ARESSCRIPTINGSERVICE']._serialized_start = 2534
    _globals['_ARESSCRIPTINGSERVICE']._serialized_end = 3207