from device import device_connection_info_pb2 as _device_connection_info_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RemoteConnectionInfo(_message.Message):
    __slots__ = ("connection_info", "address")
    CONNECTION_INFO_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    connection_info: _device_connection_info_pb2.DeviceConnectionInfo
    address: str
    def __init__(self, connection_info: _Optional[_Union[_device_connection_info_pb2.DeviceConnectionInfo, _Mapping]] = ..., address: _Optional[str] = ...) -> None: ...
