"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_connection_info.proto')
_sym_db = _symbol_database.Default()
from .. import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#device/device_connection_info.proto\x12\x15ares.datamodel.device\x1a\x11ares_struct.proto"\xef\x01\n\x14DeviceConnectionInfo\x12\x13\n\x0bdevice_name\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x11\n\tsimulated\x18\x03 \x01(\x08\x12L\n\x16serial_connection_info\x18\x04 \x01(\x0b2\'.ares.datamodel.device.SerialConnectionH\x00\x88\x01\x01\x123\n\x0fdevice_settings\x18\x05 \x01(\x0b2\x1a.ares.datamodel.AresStructB\x19\n\x17_serial_connection_info"q\n\x10SerialConnection\x12\x11\n\tport_name\x18\x01 \x01(\t\x12\x16\n\tserial_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tbaud_rate\x18\x03 \x01(\x05H\x01\x88\x01\x01B\x0c\n\n_serial_idB\x0c\n\n_baud_rateb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_connection_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DEVICECONNECTIONINFO']._serialized_start = 82
    _globals['_DEVICECONNECTIONINFO']._serialized_end = 321
    _globals['_SERIALCONNECTION']._serialized_start = 323
    _globals['_SERIALCONNECTION']._serialized_end = 436