"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/remote/remote_connection_info.proto')
_sym_db = _symbol_database.Default()
from ...device import device_connection_info_pb2 as device_dot_device__connection__info__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*device/remote/remote_connection_info.proto\x12\x15ares.datamodel.device\x1a#device/device_connection_info.proto"m\n\x14RemoteConnectionInfo\x12D\n\x0fconnection_info\x18\x01 \x01(\x0b2+.ares.datamodel.device.DeviceConnectionInfo\x12\x0f\n\x07address\x18\x02 \x01(\tb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.remote.remote_connection_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_REMOTECONNECTIONINFO']._serialized_start = 106
    _globals['_REMOTECONNECTIONINFO']._serialized_end = 215