from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SymbolTag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SYMBOL_TAG_UNSPECIFIED: _ClassVar[SymbolTag]
    SYMBOL_TAG_DEPRECATED: _ClassVar[SymbolTag]
    SYMBOL_TAG_READ_ONLY: _ClassVar[SymbolTag]
    SYMBOL_TAG_STATIC: _ClassVar[SymbolTag]
    SYMBOL_TAG_EXTENSION: _ClassVar[SymbolTag]
    SYMBOL_TAG_USER_DEFINED: _ClassVar[SymbolTag]
    SYMBOL_TAG_EXPERIMENTAL: _ClassVar[SymbolTag]
    SYMBOL_TAG_LAMBDA: _ClassVar[SymbolTag]
SYMBOL_TAG_UNSPECIFIED: SymbolTag
SYMBOL_TAG_DEPRECATED: SymbolTag
SYMBOL_TAG_READ_ONLY: SymbolTag
SYMBOL_TAG_STATIC: SymbolTag
SYMBOL_TAG_EXTENSION: SymbolTag
SYMBOL_TAG_USER_DEFINED: SymbolTag
SYMBOL_TAG_EXPERIMENTAL: SymbolTag
SYMBOL_TAG_LAMBDA: SymbolTag
