from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AresDeviceDescription(_message.Message):
    __slots__ = ("device_name", "device_id")
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_name: str
    device_id: str
    def __init__(self, device_name: _Optional[str] = ..., device_id: _Optional[str] = ...) -> None: ...
