"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_data_schema.proto')
_sym_db = _symbol_database.Default()
from . import ares_data_type_pb2 as ares__data__type__pb2
from . import ares_quantity_type_pb2 as ares__quantity__type__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from . import limits_pb2 as limits__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ares_data_schema.proto\x12\x0eares.datamodel\x1a\x14ares_data_type.proto\x1a\x18ares_quantity_type.proto\x1a\x11ares_struct.proto\x1a\x0climits.proto"\xa0\x01\n\x10AresStructSchema\x12<\n\x06fields\x18\x01 \x03(\x0b2,.ares.datamodel.AresStructSchema.FieldsEntry\x1aN\n\x0bFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b2\x1f.ares.datamodel.AresValueSchema:\x028\x01"\xa9\x04\n\x0fAresValueSchema\x12*\n\x04type\x18\x01 \x01(\x0e2\x1c.ares.datamodel.AresDataType\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x127\n\x0fquantity_schema\x18\x04 \x01(\x0b2\x1e.ares.datamodel.QuantitySchema\x125\n\x0estring_choices\x18\x05 \x01(\x0b2\x1b.ares.datamodel.StringArrayH\x00\x125\n\x0enumber_choices\x18\x06 \x01(\x0b2\x1b.ares.datamodel.NumberArrayH\x00\x12(\n\x06limits\x18\x07 \x01(\x0b2\x16.ares.datamodel.LimitsH\x00\x127\n\rstruct_schema\x18\x08 \x01(\x0b2 .ares.datamodel.AresStructSchema\x12<\n\x13list_element_schema\x18\t \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12\x1d\n\x10min_number_value\x18\n \x01(\x01H\x01\x88\x01\x01\x12\x1d\n\x10max_number_value\x18\x0b \x01(\x01H\x02\x88\x01\x01B\x13\n\x11available_choicesB\x13\n\x11_min_number_valueB\x13\n\x11_max_number_value"\xc2\x01\n\x0eQuantitySchema\x123\n\rquantity_type\x18\x01 \x01(\x0e2\x1c.ares.datamodel.QuantityType\x12\x13\n\x0bbounds_unit\x18\x02 \x01(\t\x12\x1d\n\x10min_scalar_value\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x1d\n\x10max_scalar_value\x18\x04 \x01(\x01H\x01\x88\x01\x01B\x13\n\x11_min_scalar_valueB\x13\n\x11_max_scalar_valueb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_data_schema_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._loaded_options = None
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._serialized_options = b'8\x01'
    _globals['_ARESSTRUCTSCHEMA']._serialized_start = 124
    _globals['_ARESSTRUCTSCHEMA']._serialized_end = 284
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._serialized_start = 206
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._serialized_end = 284
    _globals['_ARESVALUESCHEMA']._serialized_start = 287
    _globals['_ARESVALUESCHEMA']._serialized_end = 840
    _globals['_QUANTITYSCHEMA']._serialized_start = 843
    _globals['_QUANTITYSCHEMA']._serialized_end = 1037