from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SymbolKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SYMBOL_KIND_UNSPECIFIED: _ClassVar[SymbolKind]
    SYMBOL_KIND_DEVICE: _ClassVar[SymbolKind]
    SYMBOL_KIND_FUNCTION: _ClassVar[SymbolKind]
    SYMBOL_KIND_VARIABLE: _ClassVar[SymbolKind]
    SYMBOL_KIND_STRUCT: _ClassVar[SymbolKind]
    SYMBOL_KIND_KEYWORD: _ClassVar[SymbolKind]
    SYMBOL_KIND_PLANNER: _ClassVar[SymbolKind]
    SYMBOL_KIND_ANALYZER: _ClassVar[SymbolKind]
    SYMBOL_KIND_TYPE: _ClassVar[SymbolKind]
SYMBOL_KIND_UNSPECIFIED: SymbolKind
SYMBOL_KIND_DEVICE: SymbolKind
SYMBOL_KIND_FUNCTION: SymbolKind
SYMBOL_KIND_VARIABLE: SymbolKind
SYMBOL_KIND_STRUCT: SymbolKind
SYMBOL_KIND_KEYWORD: SymbolKind
SYMBOL_KIND_PLANNER: SymbolKind
SYMBOL_KIND_ANALYZER: SymbolKind
SYMBOL_KIND_TYPE: SymbolKind
