import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceCommandArgument(_message.Message):
    __slots__ = ("arg_name", "arg_value")
    ARG_NAME_FIELD_NUMBER: _ClassVar[int]
    ARG_VALUE_FIELD_NUMBER: _ClassVar[int]
    arg_name: str
    arg_value: _ares_struct_pb2.AresValue
    def __init__(self, arg_name: _Optional[str] = ..., arg_value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ...) -> None: ...
