"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/symbol_tag.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/symbol_tag.proto\x12\x18ares.datamodel.scripting*\xde\x01\n\tSymbolTag\x12\x1a\n\x16SYMBOL_TAG_UNSPECIFIED\x10\x00\x12\x19\n\x15SYMBOL_TAG_DEPRECATED\x10\x01\x12\x18\n\x14SYMBOL_TAG_READ_ONLY\x10\x02\x12\x15\n\x11SYMBOL_TAG_STATIC\x10\x03\x12\x18\n\x14SYMBOL_TAG_EXTENSION\x10\x04\x12\x1b\n\x17SYMBOL_TAG_USER_DEFINED\x10\x05\x12\x1b\n\x17SYMBOL_TAG_EXPERIMENTAL\x10\x06\x12\x15\n\x11SYMBOL_TAG_LAMBDA\x10\x07b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.symbol_tag_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SYMBOLTAG']._serialized_start = 57
    _globals['_SYMBOLTAG']._serialized_end = 279