from scripting import function_invocation_kind_pb2 as _function_invocation_kind_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScriptFunctionInvocation(_message.Message):
    __slots__ = ("order", "function_id", "function_name", "expression", "line", "column", "kind")
    ORDER_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_ID_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_NAME_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    LINE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    order: int
    function_id: str
    function_name: str
    expression: str
    line: int
    column: int
    kind: _function_invocation_kind_pb2.FunctionInvocationKind
    def __init__(self, order: _Optional[int] = ..., function_id: _Optional[str] = ..., function_name: _Optional[str] = ..., expression: _Optional[str] = ..., line: _Optional[int] = ..., column: _Optional[int] = ..., kind: _Optional[_Union[_function_invocation_kind_pb2.FunctionInvocationKind, str]] = ...) -> None: ...
