"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/script_symbol_metadata.proto')
_sym_db = _symbol_database.Default()
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
from .. import ares_struct_pb2 as ares__struct__pb2
from ..scripting import symbol_kind_pb2 as scripting_dot_symbol__kind__pb2
from ..scripting import symbol_tag_pb2 as scripting_dot_symbol__tag__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&scripting/script_symbol_metadata.proto\x12\x18ares.datamodel.scripting\x1a\x16ares_data_schema.proto\x1a\x11ares_struct.proto\x1a\x1bscripting/symbol_kind.proto\x1a\x1ascripting/symbol_tag.proto"\xb2\x05\n\x14ScriptSymbolMetadata\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x1e\n\x11parent_identifier\x18\x02 \x01(\tH\x01\x88\x01\x01\x122\n\x04kind\x18\x03 \x01(\x0e2$.ares.datamodel.scripting.SymbolKind\x121\n\x04tags\x18\x08 \x03(\x0e2#.ares.datamodel.scripting.SymbolTag\x12\x13\n\x06detail\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rdocumentation\x18\x05 \x01(\tH\x03\x88\x01\x01\x12P\n\x0bvalue_shape\x18\x06 \x01(\x0b29.ares.datamodel.scripting.ScriptSymbolMetadata.ValueShapeH\x00\x12V\n\x0efunction_shape\x18\x07 \x01(\x0b2<.ares.datamodel.scripting.ScriptSymbolMetadata.FunctionShapeH\x00\x1ag\n\nValueShape\x12/\n\x06schema\x18\x01 \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12(\n\x05value\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue\x1a\x7f\n\rFunctionShape\x126\n\x0cinput_schema\x18\x01 \x01(\x0b2 .ares.datamodel.AresStructSchema\x126\n\routput_schema\x18\x02 \x01(\x0b2\x1f.ares.datamodel.AresValueSchemaB\x07\n\x05shapeB\x14\n\x12_parent_identifierB\t\n\x07_detailB\x10\n\x0e_documentationb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.script_symbol_metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTSYMBOLMETADATA']._serialized_start = 169
    _globals['_SCRIPTSYMBOLMETADATA']._serialized_end = 859
    _globals['_SCRIPTSYMBOLMETADATA_VALUESHAPE']._serialized_start = 567
    _globals['_SCRIPTSYMBOLMETADATA_VALUESHAPE']._serialized_end = 670
    _globals['_SCRIPTSYMBOLMETADATA_FUNCTIONSHAPE']._serialized_start = 672
    _globals['_SCRIPTSYMBOLMETADATA_FUNCTIONSHAPE']._serialized_end = 799