from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class QuantityType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    QUANTITY_TYPE_UNSPECIFIED: _ClassVar[QuantityType]
    LENGTH: _ClassVar[QuantityType]
    AREA: _ClassVar[QuantityType]
    VOLUME: _ClassVar[QuantityType]
    DURATION: _ClassVar[QuantityType]
    SPEED: _ClassVar[QuantityType]
    ACCELERATION: _ClassVar[QuantityType]
    FREQUENCY: _ClassVar[QuantityType]
    MASS: _ClassVar[QuantityType]
    AMOUNT_OF_SUBSTANCE: _ClassVar[QuantityType]
    MOLAR_MASS: _ClassVar[QuantityType]
    TEMPERATURE: _ClassVar[QuantityType]
    TEMPERATURE_DELTA: _ClassVar[QuantityType]
    PRESSURE: _ClassVar[QuantityType]
    MOLARITY: _ClassVar[QuantityType]
    MASS_CONCENTRATION: _ClassVar[QuantityType]
    VOLUME_CONCENTRATION: _ClassVar[QuantityType]
    MASS_FRACTION: _ClassVar[QuantityType]
    DENSITY: _ClassVar[QuantityType]
    DYNAMIC_VISCOSITY: _ClassVar[QuantityType]
    KINEMATIC_VISCOSITY: _ClassVar[QuantityType]
    VOLUME_FLOW: _ClassVar[QuantityType]
    MASS_FLOW: _ClassVar[QuantityType]
    MASS_FLUX: _ClassVar[QuantityType]
    ROTATIONAL_ACCELERATION: _ClassVar[QuantityType]
    ROTATIONAL_SPEED: _ClassVar[QuantityType]
    ENERGY: _ClassVar[QuantityType]
    POWER: _ClassVar[QuantityType]
    HEAT_FLUX: _ClassVar[QuantityType]
    SPECIFIC_ENERGY: _ClassVar[QuantityType]
    THERMAL_CONDUCTIVITY: _ClassVar[QuantityType]
    FORCE: _ClassVar[QuantityType]
    FORCE_PER_LENGTH: _ClassVar[QuantityType]
    RATIO: _ClassVar[QuantityType]
    IRRADIANCE: _ClassVar[QuantityType]
    ILLUMINANCE: _ClassVar[QuantityType]
    TEMPERATURE_GRADIENT: _ClassVar[QuantityType]
    ELECTRIC_POTENTIAL: _ClassVar[QuantityType]
    ELECTRIC_CURRENT: _ClassVar[QuantityType]
    ELECTRIC_RESISTANCE: _ClassVar[QuantityType]
    ELECTRIC_CONDUCTIVITY: _ClassVar[QuantityType]
    ELECTRIC_CONDUCTANCE: _ClassVar[QuantityType]
    RATIO_CHANGE_RATE: _ClassVar[QuantityType]
    RELATIVE_HUMIDITY: _ClassVar[QuantityType]
QUANTITY_TYPE_UNSPECIFIED: QuantityType
LENGTH: QuantityType
AREA: QuantityType
VOLUME: QuantityType
DURATION: QuantityType
SPEED: QuantityType
ACCELERATION: QuantityType
FREQUENCY: QuantityType
MASS: QuantityType
AMOUNT_OF_SUBSTANCE: QuantityType
MOLAR_MASS: QuantityType
TEMPERATURE: QuantityType
TEMPERATURE_DELTA: QuantityType
PRESSURE: QuantityType
MOLARITY: QuantityType
MASS_CONCENTRATION: QuantityType
VOLUME_CONCENTRATION: QuantityType
MASS_FRACTION: QuantityType
DENSITY: QuantityType
DYNAMIC_VISCOSITY: QuantityType
KINEMATIC_VISCOSITY: QuantityType
VOLUME_FLOW: QuantityType
MASS_FLOW: QuantityType
MASS_FLUX: QuantityType
ROTATIONAL_ACCELERATION: QuantityType
ROTATIONAL_SPEED: QuantityType
ENERGY: QuantityType
POWER: QuantityType
HEAT_FLUX: QuantityType
SPECIFIC_ENERGY: QuantityType
THERMAL_CONDUCTIVITY: QuantityType
FORCE: QuantityType
FORCE_PER_LENGTH: QuantityType
RATIO: QuantityType
IRRADIANCE: QuantityType
ILLUMINANCE: QuantityType
TEMPERATURE_GRADIENT: QuantityType
ELECTRIC_POTENTIAL: QuantityType
ELECTRIC_CURRENT: QuantityType
ELECTRIC_RESISTANCE: QuantityType
ELECTRIC_CONDUCTIVITY: QuantityType
ELECTRIC_CONDUCTANCE: QuantityType
RATIO_CHANGE_RATE: QuantityType
RELATIVE_HUMIDITY: QuantityType
