"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/signature_help.proto')
_sym_db = _symbol_database.Default()
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1escripting/signature_help.proto\x12\x18ares.datamodel.scripting\x1a\x16ares_data_schema.proto"\x81\x01\n\x12SignatureParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x06schema\x18\x02 \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12\x1a\n\rdocumentation\x18\x03 \x01(\tH\x00\x88\x01\x01B\x10\n\x0e_documentation"\xca\x01\n\x11FunctionSignature\x12\r\n\x05label\x18\x01 \x01(\t\x12\x1a\n\rdocumentation\x18\x02 \x01(\tH\x00\x88\x01\x01\x12@\n\nparameters\x18\x03 \x03(\x0b2,.ares.datamodel.scripting.SignatureParameter\x126\n\rreturn_schema\x18\x04 \x01(\x0b2\x1f.ares.datamodel.AresValueSchemaB\x10\n\x0e_documentation"\xb8\x01\n\rSignatureHelp\x12?\n\nsignatures\x18\x01 \x03(\x0b2+.ares.datamodel.scripting.FunctionSignature\x12\x1d\n\x10active_signature\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10active_parameter\x18\x03 \x01(\x05H\x01\x88\x01\x01B\x13\n\x11_active_signatureB\x13\n\x11_active_parameterb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.signature_help_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SIGNATUREPARAMETER']._serialized_start = 85
    _globals['_SIGNATUREPARAMETER']._serialized_end = 214
    _globals['_FUNCTIONSIGNATURE']._serialized_start = 217
    _globals['_FUNCTIONSIGNATURE']._serialized_end = 419
    _globals['_SIGNATUREHELP']._serialized_start = 422
    _globals['_SIGNATUREHELP']._serialized_end = 606