"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/navigation.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/navigation.proto\x12\x18ares.datamodel.scripting"]\n\x0bScriptRange\x12\x12\n\nstart_line\x18\x01 \x01(\x05\x12\x14\n\x0cstart_column\x18\x02 \x01(\x05\x12\x10\n\x08end_line\x18\x03 \x01(\x05\x12\x12\n\nend_column\x18\x04 \x01(\x05"\x90\x01\n\x0eSymbolLocation\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x1e\n\x11parent_identifier\x18\x02 \x01(\tH\x00\x88\x01\x01\x124\n\x05range\x18\x03 \x01(\x0b2%.ares.datamodel.scripting.ScriptRangeB\x14\n\x12_parent_identifierb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.navigation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTRANGE']._serialized_start = 56
    _globals['_SCRIPTRANGE']._serialized_end = 149
    _globals['_SYMBOLLOCATION']._serialized_start = 152
    _globals['_SYMBOLLOCATION']._serialized_end = 296