"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_quantity_type.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ares_quantity_type.proto\x12\x0eares.datamodel*\xca\x06\n\x0cQuantityType\x12\x1d\n\x19QUANTITY_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06LENGTH\x10\x01\x12\x08\n\x04AREA\x10\x02\x12\n\n\x06VOLUME\x10\x03\x12\x0c\n\x08DURATION\x10\x04\x12\t\n\x05SPEED\x10\x05\x12\x10\n\x0cACCELERATION\x10\x06\x12\r\n\tFREQUENCY\x10\x07\x12\x08\n\x04MASS\x10\x08\x12\x17\n\x13AMOUNT_OF_SUBSTANCE\x10\t\x12\x0e\n\nMOLAR_MASS\x10\n\x12\x0f\n\x0bTEMPERATURE\x10\x0b\x12\x15\n\x11TEMPERATURE_DELTA\x10\x0c\x12\x0c\n\x08PRESSURE\x10\r\x12\x0c\n\x08MOLARITY\x10\x0e\x12\x16\n\x12MASS_CONCENTRATION\x10\x0f\x12\x18\n\x14VOLUME_CONCENTRATION\x10\x10\x12\x11\n\rMASS_FRACTION\x10\x11\x12\x0b\n\x07DENSITY\x10\x12\x12\x15\n\x11DYNAMIC_VISCOSITY\x10\x13\x12\x17\n\x13KINEMATIC_VISCOSITY\x10\x14\x12\x0f\n\x0bVOLUME_FLOW\x10\x15\x12\r\n\tMASS_FLOW\x10\x16\x12\r\n\tMASS_FLUX\x10\x17\x12\x1b\n\x17ROTATIONAL_ACCELERATION\x10\x18\x12\x14\n\x10ROTATIONAL_SPEED\x10\x19\x12\n\n\x06ENERGY\x10\x1a\x12\t\n\x05POWER\x10\x1b\x12\r\n\tHEAT_FLUX\x10\x1c\x12\x13\n\x0fSPECIFIC_ENERGY\x10\x1d\x12\x18\n\x14THERMAL_CONDUCTIVITY\x10\x1e\x12\t\n\x05FORCE\x10\x1f\x12\x14\n\x10FORCE_PER_LENGTH\x10 \x12\t\n\x05RATIO\x10!\x12\x0e\n\nIRRADIANCE\x10"\x12\x0f\n\x0bILLUMINANCE\x10#\x12\x18\n\x14TEMPERATURE_GRADIENT\x10$\x12\x16\n\x12ELECTRIC_POTENTIAL\x10%\x12\x14\n\x10ELECTRIC_CURRENT\x10&\x12\x17\n\x13ELECTRIC_RESISTANCE\x10\'\x12\x19\n\x15ELECTRIC_CONDUCTIVITY\x10(\x12\x18\n\x14ELECTRIC_CONDUCTANCE\x10)\x12\x15\n\x11RATIO_CHANGE_RATE\x10*\x12\x15\n\x11RELATIVE_HUMIDITY\x10+b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_quantity_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_QUANTITYTYPE']._serialized_start = 45
    _globals['_QUANTITYTYPE']._serialized_end = 887