"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/function_invocation_kind.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(scripting/function_invocation_kind.proto\x12\x18ares.datamodel.scripting*\xd7\x01\n\x16FunctionInvocationKind\x12(\n$FUNCTION_INVOCATION_KIND_UNSPECIFIED\x10\x00\x12#\n\x1fFUNCTION_INVOCATION_KIND_SYSTEM\x10\x01\x12&\n"FUNCTION_INVOCATION_KIND_EXTENSION\x10\x02\x12!\n\x1dFUNCTION_INVOCATION_KIND_USER\x10\x03\x12#\n\x1fFUNCTION_INVOCATION_KIND_LAMBDA\x10\x04b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.function_invocation_kind_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_FUNCTIONINVOCATIONKIND']._serialized_start = 71
    _globals['_FUNCTIONINVOCATIONKIND']._serialized_end = 286