"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/global_variable_symbol.proto')
_sym_db = _symbol_database.Default()
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
from .. import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&scripting/global_variable_symbol.proto\x12\x18ares.datamodel.scripting\x1a\x16ares_data_schema.proto\x1a\x11ares_struct.proto"\x94\x01\n\x14GlobalVariableSymbol\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12/\n\x06schema\x18\x03 \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12(\n\x05value\x18\x04 \x01(\x0b2\x19.ares.datamodel.AresValueb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.global_variable_symbol_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GLOBALVARIABLESYMBOL']._serialized_start = 112
    _globals['_GLOBALVARIABLESYMBOL']._serialized_end = 260