"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_device_driver_service.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ares_device_driver_service.proto\x12\rares.services\x1a\x1bgoogle/protobuf/empty.proto"@\n\x12DriverListResponse\x12*\n\x07drivers\x18\x01 \x03(\x0b2\x19.ares.services.DriverInfo"_\n\nDriverInfo\x12\x11\n\tdriver_id\x18\x01 \x01(\t\x12\x14\n\x0cdisplay_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x17\n\x0ffile_size_bytes\x18\x04 \x01(\x03""\n\rDriverRequest\x12\x11\n\tdriver_id\x18\x01 \x01(\t",\n\tFileChunk\x12\x0f\n\x07content\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x032\xb7\x01\n\x17AresDeviceDriverService\x12P\n\x13GetAvailableDrivers\x12\x16.google.protobuf.Empty\x1a!.ares.services.DriverListResponse\x12J\n\x0eDownloadDriver\x12\x1c.ares.services.DriverRequest\x1a\x18.ares.services.FileChunk0\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_device_driver_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DRIVERLISTRESPONSE']._serialized_start = 80
    _globals['_DRIVERLISTRESPONSE']._serialized_end = 144
    _globals['_DRIVERINFO']._serialized_start = 146
    _globals['_DRIVERINFO']._serialized_end = 241
    _globals['_DRIVERREQUEST']._serialized_start = 243
    _globals['_DRIVERREQUEST']._serialized_end = 277
    _globals['_FILECHUNK']._serialized_start = 279
    _globals['_FILECHUNK']._serialized_end = 323
    _globals['_ARESDEVICEDRIVERSERVICE']._serialized_start = 326
    _globals['_ARESDEVICEDRIVERSERVICE']._serialized_end = 509