"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/completion.proto')
_sym_db = _symbol_database.Default()
from ..scripting import script_symbol_metadata_pb2 as scripting_dot_script__symbol__metadata__pb2
from ..scripting import symbol_kind_pb2 as scripting_dot_symbol__kind__pb2
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/completion.proto\x12\x18ares.datamodel.scripting\x1a&scripting/script_symbol_metadata.proto\x1a\x1bscripting/symbol_kind.proto\x1a\x16ares_data_schema.proto"\xe8\x03\n\x0eCompletionItem\x12\r\n\x05label\x18\x01 \x01(\t\x12\x13\n\x0binsert_text\x18\x02 \x01(\t\x12F\n\x12insert_text_format\x18\x03 \x01(\x0e2*.ares.datamodel.scripting.InsertTextFormat\x12\x11\n\tsort_text\x18\x04 \x01(\t\x12@\n\x08metadata\x18\x05 \x01(\x0b2..ares.datamodel.scripting.ScriptSymbolMetadata\x12\x0e\n\x06detail\x18\x06 \x01(\t\x12\x15\n\rdocumentation\x18\x07 \x01(\t\x122\n\x04kind\x18\x08 \x01(\x0e2$.ares.datamodel.scripting.SymbolKind\x12\x19\n\x11parent_identifier\x18\t \x01(\t\x126\n\x0cinput_schema\x18\n \x01(\x0b2 .ares.datamodel.AresStructSchema\x126\n\routput_schema\x18\x0b \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12/\n\x06schema\x18\x0c \x01(\x0b2\x1f.ares.datamodel.AresValueSchema*U\n\x10InsertTextFormat\x12!\n\x1dINSERT_TEXT_FORMAT_PLAIN_TEXT\x10\x00\x12\x1e\n\x1aINSERT_TEXT_FORMAT_SNIPPET\x10\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.completion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_INSERTTEXTFORMAT']._serialized_start = 640
    _globals['_INSERTTEXTFORMAT']._serialized_end = 725
    _globals['_COMPLETIONITEM']._serialized_start = 150
    _globals['_COMPLETIONITEM']._serialized_end = 638