from google.protobuf import empty_pb2 as _empty_pb2
from planning import plan_pb2 as _plan_pb2
from planning import planner_service_capabilities_pb2 as _planner_service_capabilities_pb2
from connection import connection_state_pb2 as _connection_state_pb2
from connection import connection_status_pb2 as _connection_status_pb2
from connection import connection_info_pb2 as _connection_info_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
