"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/script_summary_step.proto')
_sym_db = _symbol_database.Default()
from ..scripting import function_invocation_kind_pb2 as scripting_dot_function__invocation__kind__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#scripting/script_summary_step.proto\x12\x18ares.datamodel.scripting\x1a(scripting/function_invocation_kind.proto"\xc7\x01\n\x18ScriptFunctionInvocation\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x13\n\x0bfunction_id\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x0c\n\x04line\x18\x05 \x01(\x05\x12\x0e\n\x06column\x18\x06 \x01(\x05\x12>\n\x04kind\x18\x07 \x01(\x0e20.ares.datamodel.scripting.FunctionInvocationKindb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.script_summary_step_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTFUNCTIONINVOCATION']._serialized_start = 108
    _globals['_SCRIPTFUNCTIONINVOCATION']._serialized_end = 307