from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class FunctionInvocationKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FUNCTION_INVOCATION_KIND_UNSPECIFIED: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_SYSTEM: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_EXTENSION: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_USER: _ClassVar[FunctionInvocationKind]
    FUNCTION_INVOCATION_KIND_LAMBDA: _ClassVar[FunctionInvocationKind]
FUNCTION_INVOCATION_KIND_UNSPECIFIED: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_SYSTEM: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_EXTENSION: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_USER: FunctionInvocationKind
FUNCTION_INVOCATION_KIND_LAMBDA: FunctionInvocationKind
