"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/diagnostic.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/diagnostic.proto\x12\x18ares.datamodel.scripting"\xbb\x01\n\nDiagnostic\x12\x12\n\nstart_line\x18\x01 \x01(\x05\x12\x14\n\x0cstart_column\x18\x02 \x01(\x05\x12\x10\n\x08end_line\x18\x03 \x01(\x05\x12\x12\n\nend_column\x18\x04 \x01(\x05\x12\x0f\n\x07message\x18\x05 \x01(\t\x12>\n\x08severity\x18\x06 \x01(\x0e2,.ares.datamodel.scripting.DiagnosticSeverity\x12\x0c\n\x04code\x18\x07 \x01(\t*\x90\x01\n\x12DiagnosticSeverity\x12\x1d\n\x19DIAGNOSTIC_SEVERITY_ERROR\x10\x00\x12\x1f\n\x1bDIAGNOSTIC_SEVERITY_WARNING\x10\x01\x12\x1c\n\x18DIAGNOSTIC_SEVERITY_INFO\x10\x02\x12\x1c\n\x18DIAGNOSTIC_SEVERITY_HINT\x10\x03b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.diagnostic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DIAGNOSTICSEVERITY']._serialized_start = 247
    _globals['_DIAGNOSTICSEVERITY']._serialized_end = 391
    _globals['_DIAGNOSTIC']._serialized_start = 57
    _globals['_DIAGNOSTIC']._serialized_end = 244